Package 'nlmixr2'

Title: Nonlinear Mixed Effects Models in Population PK/PD
Description: Fit and compare nonlinear mixed-effects models in differential equations with flexible dosing information commonly seen in pharmacokinetics and pharmacodynamics (Almquist, Leander, and Jirstrand 2015 <doi:10.1007/s10928-015-9409-1>). Differential equation solving is by compiled C code provided in the 'rxode2' package (Wang, Hallow, and James 2015 <doi:10.1002/psp4.12052>).
Authors: Matthew Fidler [aut, cre] (ORCID: <https://orcid.org/0000-0001-8538-6691>), Anne Keunecke [ctb], Rik Schoemaker [ctb] (ORCID: <https://orcid.org/0000-0002-7538-3005>), Justin Wilkins [ctb] (ORCID: <https://orcid.org/0000-0002-7099-9396>), Wenping Wang [ctb], Mirjam Trame [ctb], John Harrold [ctb], Bill Denney [ctb] (ORCID: <https://orcid.org/0000-0002-5759-428X>), Theodoros Papathanasiou [ctb], Richard Hooijmaijers [ctb], Michael Wayne Kearney [ctb] (ORCID: <https://orcid.org/0000-0002-0730-4694>)
Maintainer: Matthew Fidler <[email protected]>
License: GPL (>= 3)
Version: 6.0.0
Built: 2026-06-05 07:19:22 UTC
Source: https://github.com/nlmixr2/nlmixr2

Help Index


Check your nlmixr2 installation for potential issues

Description

Check your nlmixr2 installation for potential issues

Usage

nlmixr2CheckInstall()

Examples

nlmixr2CheckInstall()

Conflicts between the nlmixr2 and other packages

Description

This function lists all the conflicts between packages in the nlmixr2 and other packages that you have loaded.

Usage

nlmixr2conflicts()

Details

If dplyr is one of the select packages, then the following four conflicts are deliberately ignored: intersect, union, setequal, and setdiff from dplyr. These functions make the base equivalents generic, so shouldn't negatively affect any existing code.

Examples

nlmixr2conflicts()

List all nlmixr2 dependencies

Description

List all nlmixr2 dependencies

Usage

nlmixr2deps(recursive = FALSE)

Arguments

recursive

If TRUE, will also list all dependencies of nlmixr2 packages.


List all packages in the nlmixr2

Description

List all packages in the nlmixr2

Usage

nlmixr2packages(include_self = TRUE)

Arguments

include_self

Include nlmixr2 in the list?

Examples

nlmixr2packages()

Update nlmixr2 packages

Description

This will check to see if all nlmixr2 packages (and optionally, their dependencies) are up-to-date, and will install after an interactive confirmation.

Usage

nlmixr2update(recursive = FALSE)

Arguments

recursive

If TRUE, will also check all dependencies of nlmixr2 packages.

Examples

## Not run: 
nlmixr2update()

## End(Not run)